# $Id$

package MT::Plugin::FullScreenEdit;

use strict;
use MT::Plugin;
@MT::Plugin::FullScreenEdit::ISA = qw(MT::Plugin);

use vars qw($PLUGIN_NAME $VERSION);
$PLUGIN_NAME = 'FullScreenEdit';
$VERSION = '1.00';

use MT;
my $plugin = new MT::Plugin::FullScreenEdit({
    name => $PLUGIN_NAME,
    version => $VERSION,
    description => "<__trans phrase='This plugin adds the fullscreen mode to the template edit screen.'>",
    author_name => 'M-Logic, Inc.',
    author_link => 'http://labs.m-logic.jp/',
    doc_link => 'http://labs.m-logic.jp/plugins/fullscreenedit/docs/fullscreenedit.html',
    l10n_class => 'FullScreenEdit::L10N',
});

MT->add_plugin($plugin);

sub init_registry {
    my $plugin = shift;
    $plugin->registry({
    });
}

#----- Transformer
MT->add_callback('template_source.edit_template', 9, $plugin, \&hdlr_mt4_source);
MT->add_callback('template_param.edit_template', 9, $plugin, \&hdlr_mt4_param);

sub instance { $plugin; }

sub doLog {
    my ($msg) = @_; 
    return unless defined($msg);

    use MT::Log;
    my $log = MT::Log->new;
    $log->message($msg) ;
    $log->save or die $log->errstr;
}

#----- Transformer
sub hdlr_mt4_source {
    my ($eh, $app, $tmpl_ref) = @_;
    my $pattern = quotemeta(<<'HTML');
            <a href="javascript: void 0;" title="<__trans phrase="Syntax Highlight Off" escape="singlequotes">" mt:command="set-mode-codepress-off" class="command-toggle-codepress-off toolbar button"><b>Syntax Hightlight Off</b><s></s></a>
HTML
    my $replacement = $plugin->translate_templatized(<<'HTML');
<link rel="stylesheet" href="<$mt:var name="fullscreen_static_dir"$>fullscreenedit.css" type="text/css">
<script type="text/javascript" src="<$mt:var name="fullscreen_static_dir"$>fullscreenedit.js"></script>
            <a href="javascript: void 0;" title="<$mt:var name="decrease_font_size_label"$>" mt:command="font-size-smaller" class="command-font-size-smaller toolbar button2"><b>a</b><s></s></a>
            <a href="javascript: void 0;" title="<$mt:var name="increase_font_size_label"$>" mt:command="font-size-larger" class="command-font-size-larger toolbar button2"><b>A</b><s></s></a>
            <a href="javascript: void 0;" title="<$mt:var name="fullscreen_mode_label"$>" mt:command="fullscreen-mode" class="command-fullscreen-mode toolbar button"><b><$mt:var name="fullscreen_mode_label"$></b><s></s></a>
HTML
    $$tmpl_ref =~ s!($pattern)!$1$replacement!s;
    1;
}

sub hdlr_mt4_param {
    my ($eh, $app, $param, $tmpl) = @_;
    $param->{fullscreen_mode_label} = $plugin->translate('Switch fullscreen mode');
    $param->{increase_font_size_label} = $plugin->translate('Increase Font Size');
    $param->{decrease_font_size_label} = $plugin->translate('Decrease Font Size');
    $param->{fullscreen_static_dir} = $app->static_path . 'plugins/FullScreenEdit/';
    1;
}

1;
